from setuptools import setup
from textwrap import dedent
import os.path
 

with open(os.path.join(os.path.dirname(__file__), 'thonny', 'VERSION'), encoding="ASCII") as f:
    version = f.read().strip()

setup(
      name="thonny",
      version=version,
      description="Python IDE for beginners",
      url="http://thonny.cs.ut.ee",
      author="Aivar Annamaa",
      license="GPLv3",
      long_description=dedent("""
        Thonny
        ======
        
        Thonny is a Python IDE meant for learning programming.
        
        Features:
        
        * Statement stepping without breakpoints
        * Live variables during debugging
        * Stepping through evaluation of the expressions (expressions get replaced by their values)
        * Separate windows for executing function calls (helps explaining local variables and call stack; good understanding of how function calls work is especially important for understanding recursion)  
        * Variables can be explained either by using simplified model (name -> value) or by using more realistic model (name -> address/id -> value) 
        
        Screenshot:
        
        .. image:: https://bitbucket.org/plas/thonny/raw/9936e8b2c64b58efe290f3deaf11ca67436c1764/screenshot.png
            """).strip(),
      classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: MacOS X",
        "Environment :: Win32 (MS Windows)",
        "Environment :: X11 Applications",
        "Intended Audience :: Developers",
        "Intended Audience :: Education",
        "Intended Audience :: End Users/Desktop",
        "License :: Freeware",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Natural Language :: English",
        "Operating System :: MacOS",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: POSIX :: Linux",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Topic :: Education",
        "Topic :: Software Development",
        "Topic :: Software Development :: Debuggers",
      ],
      keywords="IDE education debugger",
      packages=["thonny", "thonny.plugins"],
      package_data={'': ['VERSION',  'res/*', 'backend_private/*.py', 'backend_private/thonny/*.py']},
      entry_points={
        'gui_scripts': [
            'thonny = thonny:launch',
        ]
      },      
)